@@ -41,7 +41,7 @@ use Exception::Class (
 	},
 );
 
-our $VERSION = '2.12';
+our $VERSION = '2.15';
 
 sub set_time {
 	my ( $self, %conf ) = @_;
@@ -243,6 +243,46 @@ sub with_bike {
 	return;
 }
 
+sub without_solid_stairs {
+	my ( $self, $opt ) = @_;
+
+	$self->{post}->{noSolidStairs} = $opt;
+
+	return;
+}
+
+sub without_escalators {
+	my ( $self, $opt ) = @_;
+
+	$self->{post}->{noEscalators} = $opt;
+
+	return;
+}
+
+sub without_elevators {
+	my ( $self, $opt ) = @_;
+
+	$self->{post}->{noElevators} = $opt;
+
+	return;
+}
+
+sub with_low_platform {
+	my ( $self, $opt ) = @_;
+
+	$self->{post}->{lowPlatformVhcl} = $opt;
+
+	return;
+}
+
+sub with_wheelchair {
+	my ( $self, $opt ) = @_;
+
+	$self->{post}->{wheelchair} = $opt;
+
+	return;
+}
+
 sub place {
 	my ( $self, $which, $place, $stop, $type ) = @_;
 
@@ -271,93 +311,75 @@ sub create_post {
 	my @now  = localtime( time() );
 
 	$self->{post} = {
-		changeSpeed                                        => 'normal',
-		command                                            => q{},
-		execInst                                           => q{},
-		imparedOptionsActive                               => 1,
-		inclMOT_0                                          => 'on',
-		inclMOT_1                                          => 'on',
-		inclMOT_10                                         => 'on',
-		inclMOT_11                                         => 'on',
-		inclMOT_2                                          => 'on',
-		inclMOT_3                                          => 'on',
-		inclMOT_4                                          => 'on',
-		inclMOT_5                                          => 'on',
-		inclMOT_6                                          => 'on',
-		inclMOT_7                                          => 'on',
-		inclMOT_8                                          => 'on',
-		inclMOT_9                                          => 'on',
-		includedMeans                                      => 'checkbox',
-		itOptionsActive                                    => 1,
-		itdDateDay                                         => $now[3],
-		itdDateMonth                                       => $now[4] + 1,
-		itdDateYear                                        => $now[5] + 1900,
-		itdLPxx_ShowFare                                   => q{ },
-		itdLPxx_command                                    => q{},
-		itdLPxx_enableMobilityRestrictionOptionsWithButton => q{},
-		itdLPxx_id_destination                             => ':destination',
-		itdLPxx_id_origin                                  => ':origin',
-		itdLPxx_id_via                                     => ':via',
-		itdLPxx_mapState_destination                       => q{},
-		itdLPxx_mapState_origin                            => q{},
-		itdLPxx_mapState_via                               => q{},
-		itdLPxx_mdvMap2_destination                        => q{},
-		itdLPxx_mdvMap2_origin                             => q{},
-		itdLPxx_mdvMap2_via                                => q{},
-		itdLPxx_mdvMap_destination                         => q{::},
-		itdLPxx_mdvMap_origin                              => q{::},
-		itdLPxx_mdvMap_via                                 => q{::},
-		itdLPxx_priceCalculator                            => q{},
-		itdLPxx_transpCompany                              => 'vrr',
-		itdLPxx_view                                       => q{},
-		itdTimeHour                                        => $now[2],
-		itdTimeMinute                                      => $now[1],
-		itdTripDateTimeDepArr                              => 'dep',
-		language                                           => 'de',
-		lineRestriction                                    => 403,
-		maxChanges                                         => 9,
-		nameInfo_destination                               => 'invalid',
-		nameInfo_origin                                    => 'invalid',
-		nameInfo_via                                       => 'invalid',
-		nameState_destination                              => 'empty',
-		nameState_origin                                   => 'empty',
-		nameState_via                                      => 'empty',
-		name_destination                                   => q{},
-		name_origin                                        => q{},
-		name_via                                           => q{},
-		nextDepsPerLeg                                     => 1,
-		outputFormat                                       => 'XML',
-		placeInfo_destination                              => 'invalid',
-		placeInfo_origin                                   => 'invalid',
-		placeInfo_via                                      => 'invalid',
-		placeState_destination                             => 'empty',
-		placeState_origin                                  => 'empty',
-		placeState_via                                     => 'empty',
-		place_destination                                  => q{},
-		place_origin                                       => q{},
-		place_via                                          => q{},
-		ptOptionsActive                                    => 1,
-		requestID                                          => 0,
-		routeType                                          => 'LEASTTIME',
-		sessionID                                          => 0,
-		text                                               => 1993,
-		trITArrMOT                                         => 100,
-		trITArrMOTvalue100                                 => 10,
-		trITArrMOTvalue101                                 => 10,
-		trITArrMOTvalue104                                 => 10,
-		trITArrMOTvalue105                                 => 10,
-		trITDepMOT                                         => 100,
-		trITDepMOTvalue100                                 => 10,
-		trITDepMOTvalue101                                 => 10,
-		trITDepMOTvalue104                                 => 10,
-		trITDepMOTvalue105                                 => 10,
-		typeInfo_destination                               => 'invalid',
-		typeInfo_origin                                    => 'invalid',
-		typeInfo_via                                       => 'invalid',
-		type_destination                                   => 'stop',
-		type_origin                                        => 'stop',
-		type_via                                           => 'stop',
-		useRealtime                                        => 1
+		changeSpeed            => 'normal',
+		command                => q{},
+		execInst               => q{},
+		imparedOptionsActive   => 1,
+		inclMOT_0              => 'on',
+		inclMOT_1              => 'on',
+		inclMOT_10             => 'on',
+		inclMOT_11             => 'on',
+		inclMOT_2              => 'on',
+		inclMOT_3              => 'on',
+		inclMOT_4              => 'on',
+		inclMOT_5              => 'on',
+		inclMOT_6              => 'on',
+		inclMOT_7              => 'on',
+		inclMOT_8              => 'on',
+		inclMOT_9              => 'on',
+		includedMeans          => 'checkbox',
+		itOptionsActive        => 1,
+		itdDateDay             => $now[3],
+		itdDateMonth           => $now[4] + 1,
+		itdDateYear            => $now[5] + 1900,
+		itdTimeHour            => $now[2],
+		itdTimeMinute          => $now[1],
+		itdTripDateTimeDepArr  => 'dep',
+		language               => 'de',
+		lineRestriction        => 403,
+		maxChanges             => 9,
+		nameInfo_destination   => 'invalid',
+		nameInfo_origin        => 'invalid',
+		nameInfo_via           => 'invalid',
+		nameState_destination  => 'empty',
+		nameState_origin       => 'empty',
+		nameState_via          => 'empty',
+		name_destination       => q{},
+		name_origin            => q{},
+		name_via               => q{},
+		nextDepsPerLeg         => 1,
+		outputFormat           => 'XML',
+		placeInfo_destination  => 'invalid',
+		placeInfo_origin       => 'invalid',
+		placeInfo_via          => 'invalid',
+		placeState_destination => 'empty',
+		placeState_origin      => 'empty',
+		placeState_via         => 'empty',
+		place_destination      => q{},
+		place_origin           => q{},
+		place_via              => q{},
+		ptOptionsActive        => 1,
+		requestID              => 0,
+		routeType              => 'LEASTTIME',
+		sessionID              => 0,
+		text                   => 1993,
+		trITArrMOT             => 100,
+		trITArrMOTvalue100     => 10,
+		trITArrMOTvalue101     => 10,
+		trITArrMOTvalue104     => 10,
+		trITArrMOTvalue105     => 10,
+		trITDepMOT             => 100,
+		trITDepMOTvalue100     => 10,
+		trITDepMOTvalue101     => 10,
+		trITDepMOTvalue104     => 10,
+		trITDepMOTvalue105     => 10,
+		typeInfo_destination   => 'invalid',
+		typeInfo_origin        => 'invalid',
+		typeInfo_via           => 'invalid',
+		type_destination       => 'stop',
+		type_origin            => 'stop',
+		type_via               => 'stop',
+		useRealtime            => 1
 	};
 
 	$self->place( 'origin',      @{ $conf->{origin} } );
@@ -396,6 +418,21 @@ sub create_post {
 	if ( $conf->{with_bike} ) {
 		$self->with_bike(1);
 	}
+	if ( $conf->{with_low_platform} ) {
+		$self->with_low_platform(1);
+	}
+	if ( $conf->{with_wheelchair} ) {
+		$self->with_wheelchair(1);
+	}
+	if ( $conf->{without_solid_stairs} ) {
+		$self->without_solid_stairs(1);
+	}
+	if ( $conf->{without_escalators} ) {
+		$self->without_escalators(1);
+	}
+	if ( $conf->{without_elevators} ) {
+		$self->without_elevators(1);
+	}
 
 	for my $val ( values %{ $self->{post} } ) {
 		$val = encode( 'ISO-8859-15', $val );
@@ -519,6 +556,7 @@ sub parse_cur_info {
 	);
 	for my $key ( keys %msg ) {
 		$msg{$key} = decode( 'UTF-8', $msg{$key} );
+		chomp( $msg{$key} );
 	}
 	return Travel::Routing::DE::EFA::Route::Message->new(%msg);
 }
@@ -847,16 +885,13 @@ sub get_efa_urls {
 			name      => 'Verkehrsverbund Ost-Region',
 			shortname => 'VOR',
 		},
-		{
-			url       => 'http://efaneu.vmobil.at/vvv/XSLT_TRIP_REQUEST2',
-			name      => 'Vorarlberger Verkehrsverbund',
-			shortname => 'VVV',
-		},
-		{
-			url  => 'http://fahrplan.verbundlinie.at/stv/XSLT_TRIP_REQUEST2',
-			name => 'Verkehrsverbund Steiermark',
-			shortname => 'Verbundlinie',
-		},
+
+		# Returns broken Unicode which makes Encode::decode die()
+		#{
+		#	url  => 'http://fahrplan.verbundlinie.at/stv/XSLT_TRIP_REQUEST2',
+		#	name => 'Verkehrsverbund Steiermark',
+		#	shortname => 'Verbundlinie',
+		#},
 		{
 			url       => 'http://www.linzag.at/static/XSLT_TRIP_REQUEST2',
 			name      => 'Linz AG',
@@ -873,7 +908,7 @@ sub get_efa_urls {
 			shortname => 'VRR',
 		},
 		{
-			url       => 'http://app.vrr.de/standard/XML_TRIP_REQUEST2',
+			url       => 'http://app.vrr.de/vrrstd/XML_TRIP_REQUEST2',
 			name      => 'Verkehrsverbund Rhein-Ruhr (alternative)',
 			shortname => 'VRR2',
 		},
@@ -882,6 +917,47 @@ sub get_efa_urls {
 			name      => 'Verkehrsverbund Stuttgart',
 			shortname => 'VVS',
 		},
+		{
+			url => 'http://delfi1.vvo-online.de:8080/delfi3/XSLT_TRIP_REQUEST2',
+			name      => 'Verkehrsverbund Oberelbe',
+			shortname => 'VVO',
+		},
+		{
+			url       => 'http://delfi.vrn.de/delfi/XSLT_TRIP_REQUEST2',
+			name      => 'Verkehrsverbund Rhein-Neckar (DELFI)',
+			shortname => 'VRNdelfi',
+		},
+		{
+			url  => 'http://fahrplanauskunft.vrn.de/vrn/XML_TRIP_REQUEST2',
+			name => 'Verkehrsverbund Rhein-Neckar',
+			shortname => 'VRN',
+		},
+		{
+			url       => 'http://80.146.180.107/vmv/XSLT_TRIP_REQUEST2',
+			name      => 'Verkehrsgesellschaft Mecklenburg-Vorpommern',
+			shortname => 'VMV',
+		},
+		{
+			url       => 'http://213.144.24.66/kvv2/XML_TRIP_REQUEST2',
+			name      => 'Karlsruher Verkehrsverbund',
+			shortname => 'KVV',
+		},
+		{
+			url =>
+			  'http://www.travelineeastmidlands.co.uk/em/XSLT_TRIP_REQUEST2',
+			name      => 'Traveline East Midlands',
+			shortname => 'TLEM',
+		},
+		{
+			url       => 'http://mobil.vbl.ch/vblmobil/XML_TRIP_REQUEST2',
+			name      => 'Verkehrsbetriebe Luzern',
+			shortname => 'VBL',
+		},
+		{
+			url       => 'http://bsvg.efa.de/bsvagstd/XML_TRIP_REQUEST2',
+			name      => 'Braunschweiger Verkehrs-GmbH',
+			shortname => 'BSVG',
+		},
 	);
 }
 
@@ -917,7 +993,7 @@ Travel::Routing::DE::EFA - unofficial interface to EFA-based itinerary services
 
 =head1 VERSION
 
-version 2.12
+version 2.15
 
 =head1 DESCRIPTION
 
@@ -961,10 +1037,11 @@ is not completely supported yet and may not work at all.
 
 =item * L<http://efaneu.vmobil.at/vvv/XSLT_TRIP_REQUEST2> (Vorarlberger Verkehrsverbund)
 
-=item * L<http://fahrplan.verbundlinie.at/stv/XSLT_TRIP_REQUEST2> (Verkehrsverbund Steiermark) B<[!]>
-
 =item * L<http://www.linzag.at/static/XSLT_TRIP_REQUEST2> (Linz AG) B<[!]>
 
+=item * The STV / Verkehrsverbund Steiermark is not supported since it returns
+data with broken encoding
+
 =back
 
 =item * Germany
@@ -1043,7 +1120,7 @@ Otherwise: Do not take stops close to stop/start into account.
 
 =item B<train_type> => B<local>|B<ic>|B<ice>
 
-Include only local trains into itinarery (default), all but ICEs, or all.
+Include only local trains into itinerary (default), all but ICEs, or all.
 
 The latter two are usually way more expensive for short routes.
 
@@ -1057,6 +1134,31 @@ If true: Request connections allowing passengers with bikes. Note that the
 backed may return an empty result if no such connection exists or bike-support
 simply isn't known.
 
+=item B<with_low_platform> => B<0>|B<1>
+
+If true: Request connections which only use low-platform ("Niederflur")
+vehicles. Note that the backed will return an empty result if no such
+connection exists.
+
+=item B<with_wheelchair> => B<0>|B<1>
+
+If true: Request connections which are wheelchair-accessible. Again, note that
+the backend may return an empty result if no such connection exists or
+wheelchair-support isn't known.
+
+=item B<without_elevators> => B<0>|B<1>
+
+If true: Request that transfers do not require usage of elevators.
+
+=item B<without_escalators> => B<0>|B<1>
+
+If true: Request that transfers do not require usage of escalators.
+
+=item B<without_solid_stairs> => B<0>|B<1>
+
+If true: Request that transfers do not require stairs to be taken (i.e.
+ramps, escalators, elevators or similar must be available).
+
 =item B<lwp_options> => I<\%hashref>
 
 Options to pass to C<< LWP::UserAgent->new >>.
